@require(prototype, symbol, return_value, parameters, callable_type, tags, extra) @extends('base_symbol.html') @def header():

### `@symbol.link.title`

@end @def content(): @prototype @symbol.formatted_doc @if parameters:

#### Parameters

@for parameter in parameters: @parameter @end

@end @if return_value: @return_value @end @if extra: \ @for name, ex in extra.iteritems():

@name :\ @ex

@end @end @for tag in tags.values():

@tag.name\ @if tag.description: : @tag.description @end

@end \ @end